@@ -20,6 +20,8 @@ describe 'heat' do
       :keystone_password     => 'secretpassword',
       :heat_clients_url      => '<SERVICE DEFAULT>',
       :purge_config          => false,
+      :yaql_limit_iterators  => 400,
+      :yaql_memory_quota     => 20000,
     }
   end
 
@@ -58,7 +60,6 @@ describe 'heat' do
     it_configures 'with SSL enabled without kombu'
     it_configures 'with SSL disabled'
     it_configures 'with SSL wrongly configured'
-    it_configures "with auth_plugin"
     it_configures 'with enable_stack_adopt and enable_stack_abandon set'
     it_configures 'with notification_driver set to a string'
 
@@ -90,6 +91,10 @@ describe 'heat' do
       is_expected.to contain_class('heat::db::sync')
     end
 
+    it 'configures host' do
+      is_expected.to contain_heat_config('DEFAULT/host').with_value('<SERVICE DEFAULT>')
+    end
+
     it 'configures max_template_size' do
       is_expected.to contain_heat_config('DEFAULT/max_template_size').with_value('<SERVICE DEFAULT>')
     end
@@ -108,8 +113,8 @@ describe 'heat' do
       is_expected.to contain_heat_config('trustee/user_domain_name').with_value( 'Default' )
     end
 
-    it 'configures auth_plugin' do
-      is_expected.to contain_heat_config('trustee/auth_plugin').with_value( 'password' )
+    it 'configures auth_type' do
+      is_expected.to contain_heat_config('trustee/auth_type').with_value( 'password' )
     end
 
     it 'configures auth_url' do
@@ -132,6 +137,14 @@ describe 'heat' do
       is_expected.to contain_heat_config('ec2authtoken/auth_uri').with_value( params[:keystone_ec2_uri] )
     end
 
+    it 'configures yaql_limit_iterators' do
+      is_expected.to contain_heat_config('yaql/limit_iterators').with_value( params[:yaql_limit_iterators] )
+    end
+
+    it 'configures yaql_memory_quota' do
+      is_expected.to contain_heat_config('yaql/memory_quota').with_value( params[:yaql_memory_quota] )
+    end
+
     it { is_expected.to contain_heat_config('paste_deploy/flavor').with_value('keystone') }
 
     it 'configures notification_driver' do
@@ -147,10 +160,6 @@ describe 'heat' do
       is_expected.to contain_heat_config('clients_heat/url').with_value('<SERVICE DEFAULT>')
     end
 
-    it 'configures keystone_authtoken memcached' do
-      is_expected.to contain_heat_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>')
-    end
-
     it_configures "with default auth method"
   end
 
@@ -368,29 +377,10 @@ describe 'heat' do
   shared_examples_for "with default auth method" do
     it 'configures auth_uri, identity_uri, admin_tenant_name, admin_user, admin_password' do
       is_expected.to contain_heat_config('keystone_authtoken/auth_uri').with_value("http://127.0.0.1:5000/")
-      is_expected.to contain_heat_config('keystone_authtoken/identity_uri').with_value("http://127.0.0.1:35357/")
-      is_expected.to contain_heat_config('keystone_authtoken/admin_tenant_name').with_value("services")
-      is_expected.to contain_heat_config('keystone_authtoken/admin_user').with_value("heat")
-      is_expected.to contain_heat_config('keystone_authtoken/admin_password').with_secret( true )
-    end
-  end
-
-  shared_examples_for "with auth_plugin" do
-    before do
-      params.merge!({
-        :auth_plugin => 'password',
-      })
-    end
-    it 'configures ' do
-      is_expected.to contain_heat_config('keystone_authtoken/auth_plugin').with_value("password")
       is_expected.to contain_heat_config('keystone_authtoken/auth_url').with_value("http://127.0.0.1:35357/")
+      is_expected.to contain_heat_config('keystone_authtoken/project_name').with_value("services")
       is_expected.to contain_heat_config('keystone_authtoken/username').with_value("heat")
       is_expected.to contain_heat_config('keystone_authtoken/password').with_secret( true )
-      is_expected.to contain_heat_config('keystone_authtoken/project_name').with_value("services")
-      is_expected.to contain_heat_config('keystone_authtoken/user_domain_name').with_value('Default')
-      is_expected.to contain_heat_config('keystone_authtoken/project_domain_name').with_value('Default')
-      is_expected.to contain_heat_config('keystone_authtoken/user_domain_id').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_heat_config('keystone_authtoken/project_domain_id').with_value('<SERVICE DEFAULT>')
     end
   end
 
@@ -492,31 +482,25 @@ describe 'heat' do
     end
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily => 'Debian',
-      })
-    end
+  on_supported_os({
+    :supported_os   => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
 
-    let :platform_params do
-      { :common_package_name => 'heat-common' }
-    end
+      let :platform_params do
+        case facts[:osfamily]
+        when 'Debian'
+          { :common_package_name => 'heat-common' }
+        when 'RedHat'
+          { :common_package_name => 'openstack-heat-common' }
+        end
+      end
 
-    it_configures 'heat'
+      it_behaves_like 'heat'
+    end
   end
 
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily => 'RedHat',
-      })
-    end
-
-    let :platform_params do
-      { :common_package_name => 'openstack-heat-common' }
-    end
-
-    it_configures 'heat'
-  end
 end
